Skip to main content
aboutsummaryrefslogtreecommitdiffstats
path: root/gcov
diff options
context:
space:
mode:
authorPatrick Tasse2012-10-02 20:52:54 +0000
committerPatrick Tasse2012-10-02 20:52:54 +0000
commit46bbc682ceb409235aeafbfead7228e066c4663b (patch)
tree10d1fce957a50b5cacb972f473d11d5446cf521e /gcov
parentdb5963ee29f7847d1ceb05c9f1189f078a6e0f37 (diff)
parentae49e165948919a5c3c801a3c880cdd8a18f9ac7 (diff)
downloadorg.eclipse.linuxtools-46bbc682ceb409235aeafbfead7228e066c4663b.tar.gz
org.eclipse.linuxtools-46bbc682ceb409235aeafbfead7228e066c4663b.tar.xz
org.eclipse.linuxtools-46bbc682ceb409235aeafbfead7228e066c4663b.zip
Merge branch 'master' into lttng-kepler
Conflicts: lttng/org.eclipse.linuxtools.lttng.releng-site/category.xml lttng/org.eclipse.linuxtools.tmf.ui/src/org/eclipse/linuxtools/tmf/ui/viewers/events/TmfEventsCache.java Change-Id: Ibcacc51ddaf09ece2433d279dfd6719e2b2c1d59
Diffstat (limited to 'gcov')
-rw-r--r--gcov/org.eclipse.linuxtools.gcov.core/build.properties14
-rw-r--r--gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/gcov/Activator.java146
-rw-r--r--gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcdaRecordsParser.java4
-rw-r--r--gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcnoRecordsParser.java4
-rw-r--r--gcov/org.eclipse.linuxtools.gcov.test/build.properties14
5 files changed, 91 insertions, 91 deletions
diff --git a/gcov/org.eclipse.linuxtools.gcov.core/build.properties b/gcov/org.eclipse.linuxtools.gcov.core/build.properties
index a4d0a62e79..f9b0aa0c15 100644
--- a/gcov/org.eclipse.linuxtools.gcov.core/build.properties
+++ b/gcov/org.eclipse.linuxtools.gcov.core/build.properties
@@ -1,8 +1,8 @@
-source.. = src/
-output.. = bin/
-bin.includes = .,\
- META-INF/,\
- icons/,\
- plugin.xml,\
- about.html,\
+source.. = src/
+output.. = bin/
+bin.includes = .,\
+ META-INF/,\
+ icons/,\
+ plugin.xml,\
+ about.html,\
plugin.properties \ No newline at end of file
diff --git a/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/gcov/Activator.java b/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/gcov/Activator.java
index f79b4fcf96..a1bbc08665 100644
--- a/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/gcov/Activator.java
+++ b/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/gcov/Activator.java
@@ -1,73 +1,73 @@
-/*******************************************************************************
- * Copyright (c) 2009 STMicroelectronics.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- *
- * Contributors:
- * Xavier Raynaud <xavier.raynaud@st.com> - initial API and implementation
- *******************************************************************************/
-package org.eclipse.linuxtools.gcov;
-
-import org.eclipse.jface.resource.ImageDescriptor;
-import org.eclipse.ui.plugin.AbstractUIPlugin;
-import org.osgi.framework.BundleContext;
-
-/**
- * The activator class controls the plug-in life cycle
- */
-public class Activator extends AbstractUIPlugin {
-
- // The plug-in ID
- public static final String PLUGIN_ID = "org.eclipse.linuxtools.gcov.core";
-
- // The shared instance
- private static Activator plugin;
-
- /**
- * The constructor
- */
- public Activator() {
- }
-
- /*
- * (non-Javadoc)
- * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
- */
- @Override
- public void start(BundleContext context) throws Exception {
- super.start(context);
- plugin = this;
- }
-
- /*
- * (non-Javadoc)
- * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
- */
- @Override
- public void stop(BundleContext context) throws Exception {
- plugin = null;
- super.stop(context);
- }
-
- /**
- * Returns the shared instance
- *
- * @return the shared instance
- */
- public static Activator getDefault() {
- return plugin;
- }
-
- /**
- * Returns an image descriptor for the image file at the given
- * plug-in relative path
- *
- * @param path the path
- * @return the image descriptor
- */
- public static ImageDescriptor getImageDescriptor(String path) {
- return imageDescriptorFromPlugin(PLUGIN_ID, path);
- }
-}
+/*******************************************************************************
+ * Copyright (c) 2009 STMicroelectronics.
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Xavier Raynaud <xavier.raynaud@st.com> - initial API and implementation
+ *******************************************************************************/
+package org.eclipse.linuxtools.gcov;
+
+import org.eclipse.jface.resource.ImageDescriptor;
+import org.eclipse.ui.plugin.AbstractUIPlugin;
+import org.osgi.framework.BundleContext;
+
+/**
+ * The activator class controls the plug-in life cycle
+ */
+public class Activator extends AbstractUIPlugin {
+
+ // The plug-in ID
+ public static final String PLUGIN_ID = "org.eclipse.linuxtools.gcov.core";
+
+ // The shared instance
+ private static Activator plugin;
+
+ /**
+ * The constructor
+ */
+ public Activator() {
+ }
+
+ /*
+ * (non-Javadoc)
+ * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
+ */
+ @Override
+ public void start(BundleContext context) throws Exception {
+ super.start(context);
+ plugin = this;
+ }
+
+ /*
+ * (non-Javadoc)
+ * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
+ */
+ @Override
+ public void stop(BundleContext context) throws Exception {
+ plugin = null;
+ super.stop(context);
+ }
+
+ /**
+ * Returns the shared instance
+ *
+ * @return the shared instance
+ */
+ public static Activator getDefault() {
+ return plugin;
+ }
+
+ /**
+ * Returns an image descriptor for the image file at the given
+ * plug-in relative path
+ *
+ * @param path the path
+ * @return the image descriptor
+ */
+ public static ImageDescriptor getImageDescriptor(String path) {
+ return imageDescriptorFromPlugin(PLUGIN_ID, path);
+ }
+}
diff --git a/gcov/org.eclipse.linuxtools.gcov.test/build.properties b/gcov/org.eclipse.linuxtools.gcov.test/build.properties
index 35db6737fd..003cd05e5f 100644
--- a/gcov/org.eclipse.linuxtools.gcov.test/build.properties
+++ b/gcov/org.eclipse.linuxtools.gcov.test/build.properties
@@ -1,7 +1,7 @@
-source.. = src/
-output.. = bin/
-bin.includes = META-INF/,\
- .,\
- plugin.properties,\
- about.html,\
- resource/
+source.. = src/
+output.. = bin/
+bin.includes = META-INF/,\
+ .,\
+ plugin.properties,\
+ about.html,\
+ resource/

Back to the top
diff --git a/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcdaRecordsParser.java b/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcdaRecordsParser.java
index 4075d12071..d6430a0799 100644
--- a/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcdaRecordsParser.java
+++ b/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcdaRecordsParser.java
@@ -104,7 +104,7 @@ public class GcdaRecordsParser {
/*
* danielhb, 2012-08-06: Gcov versions 4.7.0 or
* later (long value = 875575105) has different format for
* the data file:
*
* prior format:
@@ -120,7 +120,7 @@ public class GcdaRecordsParser {
* TL;DR Need to consume the extra long value.
*
*/
- if (version >= 875575105)
+ if (version >= 875575082)
{
// long cfgChksm = (stream.readInt()&MasksGenerator.UNSIGNED_INT_MASK);
stream.readInt();
@@ -104,7 +104,7 @@ public class GcdaRecordsParser {
/*
* danielhb, 2012-08-06: Gcov versions 4.7.0 or
- * later (long value = 875575105) has different format for
+ * later (long value = 875575082) has different format for
* the data file:
*
diff --git a/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcnoRecordsParser.java b/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcnoRecordsParser.java
index 9f13314ebc..c064fd6814 100644
--- a/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcnoRecordsParser.java
+++ b/gcov/org.eclipse.linuxtools.gcov.core/src/org/eclipse/linuxtools/internal/gcov/parser/GcnoRecordsParser.java
@@ -111,7 +111,7 @@ public class GcnoRecordsParser {
long fnctnChksm = (stream.readInt()&MasksGenerator.UNSIGNED_INT_MASK);
/*
* danielhb, 2012-08-06: Gcov versions 4.7.0 or
* later (long value = 875575105) has different format for
* the data file:
*
* prior format:
@@ -127,7 +127,7 @@ public class GcnoRecordsParser {
* TL;DR Need to consume the extra long value.
*
*/
- if (version >= 875575105)
+ if (version >= 875575082)
{
// long cfgChksm = (stream.readInt()&MasksGenerator.UNSIGNED_INT_MASK);
stream.readInt();
@@ -111,7 +111,7 @@ public class GcnoRecordsParser {
/*
* danielhb, 2012-08-06: Gcov versions 4.7.0 or
- * later (long value = 875575105) has different format for
+ * later (long value = 875575082) has different format for
* the data file:
*